.. _support_chapter:

============
Getting Help
============

.. _mailing list: https://groups.google.com/group/lmfit-py
.. _github issues: https://github.com/lmfit/lmfit-py/issues

If you have questions, comments, or suggestions for LMFIT, please use the
`mailing list`_. This provides an on-line conversation that is both
archived well and can be searched easily with standard web searches. If you
find a bug in the code or documentation, use `GitHub Issues`_ to submit a
report. If you have an idea for how to solve the problem and are familiar
with Python and GitHub, submitting a GitHub Pull Request would be greatly
appreciated.

If you are unsure whether to use the mailing list or the Issue tracker,
please start a conversation on the `mailing list`_. That is, the problem
you're having may or may not be due to a bug. If it is due to a bug,
creating an Issue from the conversation is easy. If it is not a bug, the
problem will be discussed and then the Issue will be closed. While one
*can* search through closed Issues on GitHub, these are not so easily
searched, and the conversation is not easily useful to others later.
Starting the conversation on the mailing list with "How do I do this?" or
"Why didn't this work?" instead of "This should work and doesn't" is
generally preferred, and will better help others with similar questions.
Of course, there is not always an obvious way to decide if something is a
Question or an Issue, and we will try our best to engage in all
discussions.
